==> OpenCL-0.8.2.tgz: OpenCL-0.8.2/src/modebase.cpp <==
/*************************************************
* Block Cipher Mode Base Source File             *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/modebase.h>

namespace OpenCL {

/*************************************************
* Block Cipher Mode Constructor                  *
*************************************************/
BlockCipherMode::BlockCipherMode(BlockCipher* c, const std::string& name,
                                 const BlockCipherKey& key,
                                 const BlockCipherModeIV& iv,
                                 u32bit buf_size_mult) :
   BLOCK_SIZE(c->BLOCK_SIZE),
   BUFFER_SIZE(buf_size_mult * BLOCK_SIZE),
   mode_name(name)
   {
   cipher = c;
   buffer.resize(BUFFER_SIZE);
   if(iv.length())
      state.create(BLOCK_SIZE);
   cipher->set_key(key);
   reset_iv(iv);
   position = 0;
   }

/*************************************************
* Return the name of this type                   *
*************************************************/
std::string BlockCipherMode::name() const
   {
   return mode_name + "<" + cipher->name() + ">";
   }

/*************************************************
* Reset the IV                                   *
*************************************************/
void BlockCipherMode::reset_iv(const BlockCipherModeIV& new_iv)
   {
   if(new_iv.length() != state.size())
      throw Invalid_IV_Length(name(), new_iv.length());
   state.copy(new_iv, new_iv.length());
   buffer.clear();
   position = 0;
   }

}

==> OpenCL-0.8.3.tgz: OpenCL-0.8.3/src/modebase.cpp <==
/*************************************************
* Block Cipher Mode Base Source File             *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/modebase.h>

namespace OpenCL {

/*************************************************
* Block Cipher Mode Constructor                  *
*************************************************/
BlockCipherMode::BlockCipherMode(BlockCipher* c, const std::string& name,
                                 const BlockCipher_Key& key,
                                 const BlockCipherModeIV& iv,
                                 u32bit buf_size_mult) :
   BLOCK_SIZE(c->BLOCK_SIZE),
   BUFFER_SIZE(buf_size_mult * BLOCK_SIZE),
   mode_name(name)
   {
   cipher = c;
   buffer.resize(BUFFER_SIZE);
   if(iv.length())
      state.create(BLOCK_SIZE);
   reset_key(key);
   reset_iv(iv);
   position = 0;
   }

/*************************************************
* Return the name of this type                   *
*************************************************/
std::string BlockCipherMode::name() const
   {
   return mode_name + "<" + cipher->name() + ">";
   }

/*************************************************
* Set the IV                                     *
*************************************************/
void BlockCipherMode::reset_iv(const BlockCipherModeIV& new_iv)
   {
   if(new_iv.length() != state.size())
      throw Invalid_IV_Length(name(), new_iv.length());
   state.copy(new_iv, new_iv.length());
   buffer.clear();
   position = 0;
   }

/*************************************************
* Set the Key                                    *
*************************************************/
void BlockCipherMode::reset_key(const BlockCipher_Key& key)
   {
   cipher->set_key(key);
   }

}
